logrxaddin: Creation of the logrx RStudio Addin

View source: R/logrxaddin.R

logrxaddinR Documentation

Creation of the logrx RStudio Addin

Description

logrxaddin creates the miniUI for the logrx RStudio Addin

Usage

logrxaddin()

Value

MiniUI for the logrx Rstudio Addin for submitting an R file to logrx to generate a log for the file.

Examples

# It is recommended to run the Addin from the RStudio Addin drop down. However,
# you can call it from the command line.
## Not run: 
logrxaddin::logrxaddin()

## End(Not run)


logrxaddin documentation built on June 8, 2025, 1:12 p.m.