| logrxaddin | R Documentation |
logrxaddin creates the miniUI for the logrx RStudio Addin
logrxaddin()
MiniUI for the logrx Rstudio Addin for submitting an R file to logrx to generate a log for the file.
# It is recommended to run the Addin from the RStudio Addin drop down. However,
# you can call it from the command line.
## Not run:
logrxaddin::logrxaddin()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.